@@ -21,7 +21,6 @@
 
 #include "dolphin_searchsettings.h"
 #include "dolphinfacetswidget.h"
-#include "dolphinsearchinformation.h"
 
 #include <KIcon>
 #include <KLineEdit>
@@ -40,24 +39,16 @@
 #include <QToolButton>
 #include <QVBoxLayout>
 
-#include <config-nepomuk.h>
-#ifdef HAVE_NEPOMUK
-    #include <Nepomuk2/Query/AndTerm>
-    #include <Nepomuk2/Query/FileQuery>
-    #include <Nepomuk2/Query/LiteralTerm>
-    #include <Nepomuk2/Query/OrTerm>
-    #include <Nepomuk2/Query/Query>
-    #include <Nepomuk2/Query/QueryParser>
-    #include <Nepomuk2/Query/ResourceTypeTerm>
-    #include <Nepomuk2/Query/ComparisonTerm>
-    #include <Nepomuk2/ResourceManager>
-    #include <Nepomuk2/Vocabulary/NFO>
+#include <config-baloo.h>
+#ifdef HAVE_BALOO
+    #include <baloo/query.h>
+    #include <baloo/term.h>
+    #include <baloo/indexerconfig.h>
 #endif
 
 DolphinSearchBox::DolphinSearchBox(QWidget* parent) :
     QWidget(parent),
     m_startedSearching(false),
-    m_readOnly(false),
     m_active(true),
     m_topLayout(0),
     m_searchLabel(0),
@@ -71,7 +62,6 @@ DolphinSearchBox::DolphinSearchBox(QWidget* parent) :
     m_facetsToggleButton(0),
     m_facetsWidget(0),
     m_searchPath(),
-    m_readOnlyQuery(),
     m_startSearchTimer(0)
 {
 }
@@ -110,13 +100,16 @@ void DolphinSearchBox::setSearchPath(const KUrl& url)
     const QString elidedLocation = metrics.elidedText(location, Qt::ElideMiddle, maxWidth);
     m_fromHereButton->setText(i18nc("action:button", "From Here (%1)", elidedLocation));
 
-    const bool showSearchFromButtons = url.isLocalFile() && !m_readOnly;
+    const bool showSearchFromButtons = url.isLocalFile();
     m_separator->setVisible(showSearchFromButtons);
     m_fromHereButton->setVisible(showSearchFromButtons);
     m_everywhereButton->setVisible(showSearchFromButtons);
 
-    const DolphinSearchInformation& searchInfo = DolphinSearchInformation::instance();
-    const bool hasFacetsSupport = searchInfo.isIndexingEnabled() && searchInfo.isPathIndexed(m_searchPath);
+    bool hasFacetsSupport = false;
+#ifdef HAVE_BALOO
+    const Baloo::IndexerConfig searchInfo;
+    hasFacetsSupport = searchInfo.fileIndexingEnabled() && searchInfo.shouldBeIndexed(m_searchPath.toLocalFile());
+#endif
     m_facetsWidget->setEnabled(hasFacetsSupport);
 }
 
@@ -128,9 +121,13 @@ KUrl DolphinSearchBox::searchPath() const
 KUrl DolphinSearchBox::urlForSearching() const
 {
     KUrl url;
-    const DolphinSearchInformation& searchInfo = DolphinSearchInformation::instance();
-    if (searchInfo.isIndexingEnabled() && searchInfo.isPathIndexed(m_searchPath)) {
-        url = nepomukUrlForSearching();
+    bool useBalooSearch = false;
+#ifdef HAVE_BALOO
+    const Baloo::IndexerConfig searchInfo;
+    useBalooSearch = searchInfo.fileIndexingEnabled() && searchInfo.shouldBeIndexed(m_searchPath.toLocalFile());
+#endif
+    if (useBalooSearch) {
+        url = balooUrlForSearching();
     } else {
         url.setProtocol("filenamesearch");
         url.addQueryItem("search", m_searchInput->text());
@@ -153,23 +150,24 @@ KUrl DolphinSearchBox::urlForSearching() const
     return url;
 }
 
-void DolphinSearchBox::selectAll()
+void DolphinSearchBox::fromSearchUrl(const KUrl& url)
 {
-    m_searchInput->selectAll();
-}
-
-void DolphinSearchBox::setReadOnly(bool readOnly, const KUrl& query)
-{
-    if (m_readOnly != readOnly || m_readOnlyQuery != query) {
-        m_readOnly = readOnly;
-        m_readOnlyQuery = query;
-        applyReadOnlyState();
+    if (url.protocol() == "baloosearch") {
+        fromBalooSearchUrl(url);
+    } else if (url.protocol() == "filenamesearch") {
+        const QMap<QString, QString>& queryItems = url.queryItems();
+        setText(queryItems.value("search"));
+        setSearchPath(queryItems.value("url"));
+        m_contentButton->setChecked(queryItems.value("checkContent") == "yes");
+    } else {
+        setText(QString());
+        setSearchPath(url);
     }
 }
 
-bool DolphinSearchBox::isReadOnly() const
+void DolphinSearchBox::selectAll()
 {
-    return m_readOnly;
+    m_searchInput->selectAll();
 }
 
 void DolphinSearchBox::setActive(bool active)
@@ -427,80 +425,83 @@ void DolphinSearchBox::init()
     connect(m_startSearchTimer, SIGNAL(timeout()), this, SLOT(emitSearchRequest()));
 
     updateFacetsToggleButton();
-    applyReadOnlyState();
 }
 
-KUrl DolphinSearchBox::nepomukUrlForSearching() const
+KUrl DolphinSearchBox::balooUrlForSearching() const
 {
-#ifdef HAVE_NEPOMUK
-    // Create the term for the text from the input-field
-    // dependent on whether a searching for content or
-    // filename is done
+#ifdef HAVE_BALOO
     const QString text = m_searchInput->text();
-    Nepomuk2::Query::Term searchLabelTerm;
-    if (m_contentButton->isChecked()) {
-        // Let Nepomuk parse the query
-        searchLabelTerm = Nepomuk2::Query::QueryParser::parseQuery(text, Nepomuk2::Query::QueryParser::DetectFilenamePattern).term();
-    } else {
-        // Search the text in the filename only
-        QString regex = QRegExp::escape(text);
-        regex.replace("\\*", QLatin1String(".*"));
-        regex.replace("\\?", QLatin1String("."));
-        regex.replace("\\", "\\\\");
-        searchLabelTerm = Nepomuk2::Query::ComparisonTerm(
-                                Nepomuk2::Vocabulary::NFO::fileName(),
-                                Nepomuk2::Query::LiteralTerm(regex),
-                                Nepomuk2::Query::ComparisonTerm::Regexp);
+
+    Baloo::Query query;
+    query.addType("File");
+    query.addType(m_facetsWidget->facetType());
+
+    Baloo::Term term(Baloo::Term::And);
+
+    Baloo::Term ratingTerm = m_facetsWidget->ratingTerm();
+    if (ratingTerm.isValid()) {
+        term.addSubTerm(ratingTerm);
     }
 
-    // Get the term from the facets and merge it with the
-    // created term from the input-field.
-    Nepomuk2::Query::Term facetsTerm = m_facetsWidget->facetsTerm();
-
-    Nepomuk2::Query::FileQuery fileQuery;
-    fileQuery.setFileMode(Nepomuk2::Query::FileQuery::QueryFilesAndFolders);
-    if (facetsTerm.isValid()) {
-        Nepomuk2::Query::AndTerm andTerm;
-        andTerm.addSubTerm(searchLabelTerm);
-        andTerm.addSubTerm(facetsTerm);
-        fileQuery.setTerm(andTerm);
-    } else {
-        fileQuery.setTerm(searchLabelTerm);
+    if (m_contentButton->isChecked()) {
+        query.setSearchString(text);
+    } else if (!text.isEmpty()) {
+        term.addSubTerm(Baloo::Term(QLatin1String("filename"), text));
     }
 
     if (m_fromHereButton->isChecked()) {
-        const bool recursive = true;
-        fileQuery.addIncludeFolder(m_searchPath, recursive);
+        query.addCustomOption("includeFolder", m_searchPath.toLocalFile());
     }
 
-    return fileQuery.toSearchUrl(i18nc("@title UDS_DISPLAY_NAME for a KIO directory listing. %1 is the query the user entered.",
-                                       "Query Results from '%1'",
-                                       text));
+    query.setTerm(term);
+
+    return query.toSearchUrl(i18nc("@title UDS_DISPLAY_NAME for a KIO directory listing. %1 is the query the user entered.",
+                                   "Query Results from '%1'", text));
 #else
     return KUrl();
 #endif
 }
 
-void DolphinSearchBox::applyReadOnlyState()
+void DolphinSearchBox::fromBalooSearchUrl(const KUrl& url)
 {
-#ifdef HAVE_NEPOMUK
-    if (m_readOnly) {
-        m_searchLabel->setText(Nepomuk2::Query::Query::titleFromQueryUrl(m_readOnlyQuery));
+#ifdef HAVE_BALOO
+    const Baloo::Query query = Baloo::Query::fromSearchUrl(url);
+    const Baloo::Term term = query.term();
+
+    // Block all signals to avoid unnecessary "searchRequest" signals
+    // while we adjust the search text and the facet widget.
+    blockSignals(true);
+
+    const QVariantHash customOptions = query.customOptions();
+    if (customOptions.contains("includeFolder")) {
+        setSearchPath(customOptions.value("includeFolder").toString());
     } else {
-#else
-    {
+        setSearchPath(QDir::homePath());
+    }
+
+    if (!query.searchString().isEmpty()) {
+        setText(query.searchString());
+    }
+
+    QStringList types = query.types();
+    types.removeOne("File"); // We are only interested in facet widget types
+    if (!types.isEmpty()) {
+        m_facetsWidget->setFacetType(types.first());
+    }
+
+    foreach (const Baloo::Term& subTerm, term.subTerms()) {
+        const QString property = subTerm.property();
+
+        if (property == QLatin1String("filename")) {
+            setText(subTerm.value().toString());
+        } else if (m_facetsWidget->isRatingTerm(subTerm)) {
+            m_facetsWidget->setRatingTerm(subTerm);
+        }
+    }
+
+    m_startSearchTimer->stop();
+    blockSignals(false);
 #endif
-        m_searchLabel->setText(i18nc("@label:textbox", "Find:"));
-    }
-
-    m_searchInput->setVisible(!m_readOnly);
-    m_optionsScrollArea->setVisible(!m_readOnly);
-
-    if (m_readOnly) {
-        m_facetsWidget->hide();
-    } else {
-        m_facetsWidget->setVisible(SearchSettings::showFacetsWidget());
-    }
 }
 
 void DolphinSearchBox::updateFacetsToggleButton()
